@@ -3,6 +3,7 @@ from connect.autogen import connect_util_Collection as Collection
 from connect.autogen import connect_util_DateTime as DateTime
 from connect.autogen import connect_util_Dictionary as Dictionary
 from connect.autogen import connect_util_Diff as Diff
+from connect.autogen import connect_util_ExcelWriter as ExcelWriter
 from connect.autogen import connect_util_Util as Util
 
 
@@ -12,5 +13,6 @@ __all__ = [
     'DateTime',
     'Dictionary',
     'Diff',
+    'ExcelWriter',
     'Util',
 ]
